window.Gleam.initSearch([{"doc":"sketch_lustre","title":"sketch_lustre","content":"# Sketch Lustre\n\n&gt; In case you&#39;re here and don&#39;t know Sketch, take a look at\n&gt; [`sketch` package](https://hexdocs.pm/sketch)!\n\n&gt; This readme is a carbon-copy of the Sketch Lustre section in `sketch` readme.\n\n## Setup\n\nIf you&#39;re using Lustre (which is strongly recommended), `sketch_lustre` got you.\n`sketch_lustre` exposes one entrypoint, `sketch/lustre`, containing everything\nneeded to get started.\n\n```gleam\n// main.gleam\nimport lustre\nimport sketch\nimport sketch/lustre as sketch_lustre\n\npub fn main() {\n  // Initialise the cache. Two strategies can be used in browser, only one\n  // on server-side.\n  let assert Ok(cache) = sketch.cache(strategy: sketch.Ephemeral)\n  // Select the output of the generated stylesheet.\n  sketch_lustre.node()\n  // Add the sketch CSS generation &quot;view middleware&quot;.\n  |&gt; sketch_lustre.compose(view, cache)\n  // Give the new view function to lustre runtime!\n  |&gt; lustre.simple(init, update, _)\n  // And voilà!\n  |&gt; lustre.start(&quot;#app&quot;, Nil)\n}\n```\n\n## Usage\n\n`sketch_lustre` exposes two modules to help you build your site, similarly to\nLustre: `sketch/lustre/element` and `sketch/lustre/element/html`. The first one\nlet you use raw element generation and exposes the Sketch Lustre `Element(msg)`\ntype, that can be used (almost) interchangeably with Lustre, and element\nhelpers, i.e. `element`, `fragment`, or even `keyed`.\n\nBecause a `sketch_lustre` view function expects an\n`sketch/lustre/element.Element(msg)` to paint, you should now write all your\nview functions to return Sketch elements. All Sketch elements can be\ninstanciated with `element`, or with the corresponding\n`sketch/lustre/element/html.element`. An element accepts the same thing as a\nLustre element, but includes a `sketch.Class` value as first argument. That\nclass will be applied to the final generated element.\n\nNB: all elements can be generated using the correct function, or using its\n&quot;underscored&quot; version. In the second case, Sketch Lustre behaves _exactly_ like\nLustre, and will not add another class. This is helpful when you want to use a\nsimple node, without any class linked on it.\n\n```gleam\nimport sketch\nimport sketch/lustre/element\nimport sketch/lustre/element/html\nimport sketch/size.{px}\n\nfn main_style() {\n  sketch.class([\n    sketch.background(&quot;red&quot;),\n    sketch.font_size(px(16)),\n  ])\n}\n\nfn view(model: Int) {\n  html.div(main_style(), [], [\n    html.div_([], [h.text(int.to_string(model))]),\n  ])\n}\n```\n\nAnd you&#39;re done! Enjoy your Lustre app, Sketch-enhanced!\n\n## Final notes\n\n### On Sketch Lustre Element\n\nA Sketch `Element(msg)` is extremely similar to a Lustre `Element(msg)`,\nexcepted it carries styles information on top. Going from a\n`sketch/lustre/element.Element(msg)` to a `lustre/element.Element(msg)` is\nstraightforward, by using `sketch/lustre/element.unstyled`. The opposite (going\nfrom a Lustre element to a Sketch Lustre element) is also possible by using\n`sketch/lustre/element.styled`!\n\n### Usage with Shadow DOM\n\nIn browser, Sketch can work with a Shadow DOM, in order to hide the compiled\nstyles from the rest of the application. To do it, you can use\n[`plinth`](https://github.com/CrowdHailer/plinth). This allows to create a\n`ShadowRoot`, to use\n[`sketch/options.shadow_root()`](https://hexdocs.pm/sketch/sketch/options.html#shadow_root).\nIn the same way you can initialize the cache to render in document or in a\n`style` node, you can now use a Shadow Root to paint styles in your application!\n","url":"index.html"},{"doc":"sketch/lustre/element","title":"Element","content":"pub opaque type Element(msg)\n\n\nSynonyms:\nsketch/lustre/element.Element\nsketch/lustre/element Element","url":"sketch/lustre/element.html#Element"},{"doc":"sketch/lustre/element","title":"element","content":"pub fn element(\n  tag tag: String,\n  class class: Class,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.element\nsketch/lustre/element element","url":"sketch/lustre/element.html#element"},{"doc":"sketch/lustre/element","title":"element_","content":"pub fn element_(\n  tag tag: String,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.element_\nsketch/lustre/element element_","url":"sketch/lustre/element.html#element_"},{"doc":"sketch/lustre/element","title":"fragment","content":"pub fn fragment(children: List(Element(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.fragment\nsketch/lustre/element fragment","url":"sketch/lustre/element.html#fragment"},{"doc":"sketch/lustre/element","title":"keyed","content":"pub fn keyed(\n  element: fn(List(Element(a))) -&gt; Element(a),\n  children: List(#(String, Element(a))),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.keyed\nsketch/lustre/element keyed","url":"sketch/lustre/element.html#keyed"},{"doc":"sketch/lustre/element","title":"map","content":"pub fn map(element: Element(a), mapper: fn(a) -&gt; b) -&gt; Element(b)\n\nSynonyms:\nsketch/lustre/element.map\nsketch/lustre/element map","url":"sketch/lustre/element.html#map"},{"doc":"sketch/lustre/element","title":"namespaced","content":"pub fn namespaced(\n  namespace namespace: String,\n  tag tag: String,\n  class class: Class,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.namespaced\nsketch/lustre/element namespaced","url":"sketch/lustre/element.html#namespaced"},{"doc":"sketch/lustre/element","title":"namespaced_","content":"pub fn namespaced_(\n  namespace namespace: String,\n  tag tag: String,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.namespaced_\nsketch/lustre/element namespaced_","url":"sketch/lustre/element.html#namespaced_"},{"doc":"sketch/lustre/element","title":"none","content":"pub fn none() -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.none\nsketch/lustre/element none","url":"sketch/lustre/element.html#none"},{"doc":"sketch/lustre/element","title":"styled","content":"pub fn styled(\n  element: Element(a),\n) -&gt; sketch/lustre/element.Element(a)\n\nSynonyms:\nsketch/lustre/element.styled\nsketch/lustre/element styled","url":"sketch/lustre/element.html#styled"},{"doc":"sketch/lustre/element","title":"text","content":"pub fn text(content: String) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element.text\nsketch/lustre/element text","url":"sketch/lustre/element.html#text"},{"doc":"sketch/lustre/element","title":"unstyled","content":"pub fn unstyled(\n  cache: Cache,\n  element: Element(a),\n) -&gt; #(Cache, lustre/internals/vdom.Element(a))\n\nSynonyms:\nsketch/lustre/element.unstyled\nsketch/lustre/element unstyled","url":"sketch/lustre/element.html#unstyled"},{"doc":"sketch/lustre/element","title":"sketch/lustre/element","content":"","url":"sketch/lustre/element.html"},{"doc":"sketch/lustre","title":"Options","content":"pub opaque type Options\n Options to indicate where to output the StyleSheet.\n Can be a Node in DOM, a `CSSStyleSheet` in `document` or in a shadow root.\n\nSynonyms:\nsketch/lustre.Options\nsketch/lustre Options","url":"sketch/lustre.html#Options"},{"doc":"sketch/lustre","title":"compose","content":"pub fn compose(\n  options: Options,\n  view: fn(a) -&gt; Element(b),\n  cache: Cache,\n) -&gt; fn(a) -&gt; lustre/internals/vdom.Element(b)\n Wrap the view function in lustre. Be careful, on BEAM, sketch will add an\n additional `div` at the root of the HTML tree, to inject the styles in the\n app, currently due to a fragment bug.\n This should have no impact on your app.\nSynonyms:\nsketch/lustre.compose\nsketch/lustre compose","url":"sketch/lustre.html#compose"},{"doc":"sketch/lustre","title":"document","content":"pub fn document() -&gt; Options\n Output the StyleSheet in a `CSSStyleSheet` in `document`.\n `document` cannot be used on server.\nSynonyms:\nsketch/lustre.document\nsketch/lustre document","url":"sketch/lustre.html#document"},{"doc":"sketch/lustre","title":"node","content":"pub fn node() -&gt; Options\n Output the StyleSheet in a `style` tag in DOM.\nSynonyms:\nsketch/lustre.node\nsketch/lustre node","url":"sketch/lustre.html#node"},{"doc":"sketch/lustre","title":"shadow","content":"pub fn shadow(root: ShadowRoot) -&gt; Options\n Output the StyleSheet in a `CSSStyleSheet` in a shadow root.\n `shadow` cannot be used on server.\nSynonyms:\nsketch/lustre.shadow\nsketch/lustre shadow","url":"sketch/lustre.html#shadow"},{"doc":"sketch/lustre","title":"ssr","content":"pub fn ssr(\n  el: Element(a),\n  cache: Cache,\n) -&gt; lustre/internals/vdom.Element(a)\n Take an Element, and overloads the content with the correct styles from sketch.\n Can only be used on BEAM.\nSynonyms:\nsketch/lustre.ssr\nsketch/lustre ssr","url":"sketch/lustre.html#ssr"},{"doc":"sketch/lustre","title":"sketch/lustre","content":"","url":"sketch/lustre.html"},{"doc":"sketch/lustre/element/html","title":"a","content":"pub fn a(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.a\nsketch/lustre/element/html a","url":"sketch/lustre/element/html.html#a"},{"doc":"sketch/lustre/element/html","title":"a_","content":"pub fn a_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.a_\nsketch/lustre/element/html a_","url":"sketch/lustre/element/html.html#a_"},{"doc":"sketch/lustre/element/html","title":"abbr","content":"pub fn abbr(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.abbr\nsketch/lustre/element/html abbr","url":"sketch/lustre/element/html.html#abbr"},{"doc":"sketch/lustre/element/html","title":"abbr_","content":"pub fn abbr_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.abbr_\nsketch/lustre/element/html abbr_","url":"sketch/lustre/element/html.html#abbr_"},{"doc":"sketch/lustre/element/html","title":"address","content":"pub fn address(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.address\nsketch/lustre/element/html address","url":"sketch/lustre/element/html.html#address"},{"doc":"sketch/lustre/element/html","title":"address_","content":"pub fn address_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.address_\nsketch/lustre/element/html address_","url":"sketch/lustre/element/html.html#address_"},{"doc":"sketch/lustre/element/html","title":"area","content":"pub fn area(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.area\nsketch/lustre/element/html area","url":"sketch/lustre/element/html.html#area"},{"doc":"sketch/lustre/element/html","title":"area_","content":"pub fn area_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.area_\nsketch/lustre/element/html area_","url":"sketch/lustre/element/html.html#area_"},{"doc":"sketch/lustre/element/html","title":"article","content":"pub fn article(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.article\nsketch/lustre/element/html article","url":"sketch/lustre/element/html.html#article"},{"doc":"sketch/lustre/element/html","title":"article_","content":"pub fn article_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.article_\nsketch/lustre/element/html article_","url":"sketch/lustre/element/html.html#article_"},{"doc":"sketch/lustre/element/html","title":"aside","content":"pub fn aside(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.aside\nsketch/lustre/element/html aside","url":"sketch/lustre/element/html.html#aside"},{"doc":"sketch/lustre/element/html","title":"aside_","content":"pub fn aside_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.aside_\nsketch/lustre/element/html aside_","url":"sketch/lustre/element/html.html#aside_"},{"doc":"sketch/lustre/element/html","title":"audio","content":"pub fn audio(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.audio\nsketch/lustre/element/html audio","url":"sketch/lustre/element/html.html#audio"},{"doc":"sketch/lustre/element/html","title":"audio_","content":"pub fn audio_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.audio_\nsketch/lustre/element/html audio_","url":"sketch/lustre/element/html.html#audio_"},{"doc":"sketch/lustre/element/html","title":"b","content":"pub fn b(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.b\nsketch/lustre/element/html b","url":"sketch/lustre/element/html.html#b"},{"doc":"sketch/lustre/element/html","title":"b_","content":"pub fn b_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.b_\nsketch/lustre/element/html b_","url":"sketch/lustre/element/html.html#b_"},{"doc":"sketch/lustre/element/html","title":"base","content":"pub fn base(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.base\nsketch/lustre/element/html base","url":"sketch/lustre/element/html.html#base"},{"doc":"sketch/lustre/element/html","title":"bdi","content":"pub fn bdi(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.bdi\nsketch/lustre/element/html bdi","url":"sketch/lustre/element/html.html#bdi"},{"doc":"sketch/lustre/element/html","title":"bdi_","content":"pub fn bdi_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.bdi_\nsketch/lustre/element/html bdi_","url":"sketch/lustre/element/html.html#bdi_"},{"doc":"sketch/lustre/element/html","title":"bdo","content":"pub fn bdo(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.bdo\nsketch/lustre/element/html bdo","url":"sketch/lustre/element/html.html#bdo"},{"doc":"sketch/lustre/element/html","title":"bdo_","content":"pub fn bdo_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.bdo_\nsketch/lustre/element/html bdo_","url":"sketch/lustre/element/html.html#bdo_"},{"doc":"sketch/lustre/element/html","title":"blockquote","content":"pub fn blockquote(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.blockquote\nsketch/lustre/element/html blockquote","url":"sketch/lustre/element/html.html#blockquote"},{"doc":"sketch/lustre/element/html","title":"blockquote_","content":"pub fn blockquote_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.blockquote_\nsketch/lustre/element/html blockquote_","url":"sketch/lustre/element/html.html#blockquote_"},{"doc":"sketch/lustre/element/html","title":"body","content":"pub fn body(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.body\nsketch/lustre/element/html body","url":"sketch/lustre/element/html.html#body"},{"doc":"sketch/lustre/element/html","title":"body_","content":"pub fn body_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.body_\nsketch/lustre/element/html body_","url":"sketch/lustre/element/html.html#body_"},{"doc":"sketch/lustre/element/html","title":"br","content":"pub fn br(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.br\nsketch/lustre/element/html br","url":"sketch/lustre/element/html.html#br"},{"doc":"sketch/lustre/element/html","title":"br_","content":"pub fn br_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.br_\nsketch/lustre/element/html br_","url":"sketch/lustre/element/html.html#br_"},{"doc":"sketch/lustre/element/html","title":"button","content":"pub fn button(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.button\nsketch/lustre/element/html button","url":"sketch/lustre/element/html.html#button"},{"doc":"sketch/lustre/element/html","title":"button_","content":"pub fn button_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.button_\nsketch/lustre/element/html button_","url":"sketch/lustre/element/html.html#button_"},{"doc":"sketch/lustre/element/html","title":"canvas","content":"pub fn canvas(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.canvas\nsketch/lustre/element/html canvas","url":"sketch/lustre/element/html.html#canvas"},{"doc":"sketch/lustre/element/html","title":"canvas_","content":"pub fn canvas_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.canvas_\nsketch/lustre/element/html canvas_","url":"sketch/lustre/element/html.html#canvas_"},{"doc":"sketch/lustre/element/html","title":"caption","content":"pub fn caption(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.caption\nsketch/lustre/element/html caption","url":"sketch/lustre/element/html.html#caption"},{"doc":"sketch/lustre/element/html","title":"caption_","content":"pub fn caption_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.caption_\nsketch/lustre/element/html caption_","url":"sketch/lustre/element/html.html#caption_"},{"doc":"sketch/lustre/element/html","title":"cite","content":"pub fn cite(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.cite\nsketch/lustre/element/html cite","url":"sketch/lustre/element/html.html#cite"},{"doc":"sketch/lustre/element/html","title":"cite_","content":"pub fn cite_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.cite_\nsketch/lustre/element/html cite_","url":"sketch/lustre/element/html.html#cite_"},{"doc":"sketch/lustre/element/html","title":"code","content":"pub fn code(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.code\nsketch/lustre/element/html code","url":"sketch/lustre/element/html.html#code"},{"doc":"sketch/lustre/element/html","title":"code_","content":"pub fn code_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.code_\nsketch/lustre/element/html code_","url":"sketch/lustre/element/html.html#code_"},{"doc":"sketch/lustre/element/html","title":"col","content":"pub fn col(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.col\nsketch/lustre/element/html col","url":"sketch/lustre/element/html.html#col"},{"doc":"sketch/lustre/element/html","title":"col_","content":"pub fn col_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.col_\nsketch/lustre/element/html col_","url":"sketch/lustre/element/html.html#col_"},{"doc":"sketch/lustre/element/html","title":"colgroup","content":"pub fn colgroup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.colgroup\nsketch/lustre/element/html colgroup","url":"sketch/lustre/element/html.html#colgroup"},{"doc":"sketch/lustre/element/html","title":"colgroup_","content":"pub fn colgroup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.colgroup_\nsketch/lustre/element/html colgroup_","url":"sketch/lustre/element/html.html#colgroup_"},{"doc":"sketch/lustre/element/html","title":"data","content":"pub fn data(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.data\nsketch/lustre/element/html data","url":"sketch/lustre/element/html.html#data"},{"doc":"sketch/lustre/element/html","title":"data_","content":"pub fn data_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.data_\nsketch/lustre/element/html data_","url":"sketch/lustre/element/html.html#data_"},{"doc":"sketch/lustre/element/html","title":"datalist","content":"pub fn datalist(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.datalist\nsketch/lustre/element/html datalist","url":"sketch/lustre/element/html.html#datalist"},{"doc":"sketch/lustre/element/html","title":"datalist_","content":"pub fn datalist_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.datalist_\nsketch/lustre/element/html datalist_","url":"sketch/lustre/element/html.html#datalist_"},{"doc":"sketch/lustre/element/html","title":"dd","content":"pub fn dd(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dd\nsketch/lustre/element/html dd","url":"sketch/lustre/element/html.html#dd"},{"doc":"sketch/lustre/element/html","title":"dd_","content":"pub fn dd_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dd_\nsketch/lustre/element/html dd_","url":"sketch/lustre/element/html.html#dd_"},{"doc":"sketch/lustre/element/html","title":"del","content":"pub fn del(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.del\nsketch/lustre/element/html del","url":"sketch/lustre/element/html.html#del"},{"doc":"sketch/lustre/element/html","title":"del_","content":"pub fn del_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.del_\nsketch/lustre/element/html del_","url":"sketch/lustre/element/html.html#del_"},{"doc":"sketch/lustre/element/html","title":"details","content":"pub fn details(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.details\nsketch/lustre/element/html details","url":"sketch/lustre/element/html.html#details"},{"doc":"sketch/lustre/element/html","title":"details_","content":"pub fn details_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.details_\nsketch/lustre/element/html details_","url":"sketch/lustre/element/html.html#details_"},{"doc":"sketch/lustre/element/html","title":"dfn","content":"pub fn dfn(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dfn\nsketch/lustre/element/html dfn","url":"sketch/lustre/element/html.html#dfn"},{"doc":"sketch/lustre/element/html","title":"dfn_","content":"pub fn dfn_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dfn_\nsketch/lustre/element/html dfn_","url":"sketch/lustre/element/html.html#dfn_"},{"doc":"sketch/lustre/element/html","title":"dialog","content":"pub fn dialog(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dialog\nsketch/lustre/element/html dialog","url":"sketch/lustre/element/html.html#dialog"},{"doc":"sketch/lustre/element/html","title":"dialog_","content":"pub fn dialog_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dialog_\nsketch/lustre/element/html dialog_","url":"sketch/lustre/element/html.html#dialog_"},{"doc":"sketch/lustre/element/html","title":"div","content":"pub fn div(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.div\nsketch/lustre/element/html div","url":"sketch/lustre/element/html.html#div"},{"doc":"sketch/lustre/element/html","title":"div_","content":"pub fn div_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.div_\nsketch/lustre/element/html div_","url":"sketch/lustre/element/html.html#div_"},{"doc":"sketch/lustre/element/html","title":"dl","content":"pub fn dl(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dl\nsketch/lustre/element/html dl","url":"sketch/lustre/element/html.html#dl"},{"doc":"sketch/lustre/element/html","title":"dl_","content":"pub fn dl_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dl_\nsketch/lustre/element/html dl_","url":"sketch/lustre/element/html.html#dl_"},{"doc":"sketch/lustre/element/html","title":"dt","content":"pub fn dt(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dt\nsketch/lustre/element/html dt","url":"sketch/lustre/element/html.html#dt"},{"doc":"sketch/lustre/element/html","title":"dt_","content":"pub fn dt_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.dt_\nsketch/lustre/element/html dt_","url":"sketch/lustre/element/html.html#dt_"},{"doc":"sketch/lustre/element/html","title":"em","content":"pub fn em(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.em\nsketch/lustre/element/html em","url":"sketch/lustre/element/html.html#em"},{"doc":"sketch/lustre/element/html","title":"em_","content":"pub fn em_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.em_\nsketch/lustre/element/html em_","url":"sketch/lustre/element/html.html#em_"},{"doc":"sketch/lustre/element/html","title":"embed","content":"pub fn embed(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.embed\nsketch/lustre/element/html embed","url":"sketch/lustre/element/html.html#embed"},{"doc":"sketch/lustre/element/html","title":"embed_","content":"pub fn embed_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.embed_\nsketch/lustre/element/html embed_","url":"sketch/lustre/element/html.html#embed_"},{"doc":"sketch/lustre/element/html","title":"fieldset","content":"pub fn fieldset(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.fieldset\nsketch/lustre/element/html fieldset","url":"sketch/lustre/element/html.html#fieldset"},{"doc":"sketch/lustre/element/html","title":"fieldset_","content":"pub fn fieldset_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.fieldset_\nsketch/lustre/element/html fieldset_","url":"sketch/lustre/element/html.html#fieldset_"},{"doc":"sketch/lustre/element/html","title":"figcaption","content":"pub fn figcaption(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.figcaption\nsketch/lustre/element/html figcaption","url":"sketch/lustre/element/html.html#figcaption"},{"doc":"sketch/lustre/element/html","title":"figcaption_","content":"pub fn figcaption_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.figcaption_\nsketch/lustre/element/html figcaption_","url":"sketch/lustre/element/html.html#figcaption_"},{"doc":"sketch/lustre/element/html","title":"figure","content":"pub fn figure(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.figure\nsketch/lustre/element/html figure","url":"sketch/lustre/element/html.html#figure"},{"doc":"sketch/lustre/element/html","title":"figure_","content":"pub fn figure_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.figure_\nsketch/lustre/element/html figure_","url":"sketch/lustre/element/html.html#figure_"},{"doc":"sketch/lustre/element/html","title":"footer","content":"pub fn footer(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.footer\nsketch/lustre/element/html footer","url":"sketch/lustre/element/html.html#footer"},{"doc":"sketch/lustre/element/html","title":"footer_","content":"pub fn footer_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.footer_\nsketch/lustre/element/html footer_","url":"sketch/lustre/element/html.html#footer_"},{"doc":"sketch/lustre/element/html","title":"form","content":"pub fn form(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.form\nsketch/lustre/element/html form","url":"sketch/lustre/element/html.html#form"},{"doc":"sketch/lustre/element/html","title":"form_","content":"pub fn form_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.form_\nsketch/lustre/element/html form_","url":"sketch/lustre/element/html.html#form_"},{"doc":"sketch/lustre/element/html","title":"h1","content":"pub fn h1(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h1\nsketch/lustre/element/html h1","url":"sketch/lustre/element/html.html#h1"},{"doc":"sketch/lustre/element/html","title":"h1_","content":"pub fn h1_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h1_\nsketch/lustre/element/html h1_","url":"sketch/lustre/element/html.html#h1_"},{"doc":"sketch/lustre/element/html","title":"h2","content":"pub fn h2(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h2\nsketch/lustre/element/html h2","url":"sketch/lustre/element/html.html#h2"},{"doc":"sketch/lustre/element/html","title":"h2_","content":"pub fn h2_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h2_\nsketch/lustre/element/html h2_","url":"sketch/lustre/element/html.html#h2_"},{"doc":"sketch/lustre/element/html","title":"h3","content":"pub fn h3(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h3\nsketch/lustre/element/html h3","url":"sketch/lustre/element/html.html#h3"},{"doc":"sketch/lustre/element/html","title":"h3_","content":"pub fn h3_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h3_\nsketch/lustre/element/html h3_","url":"sketch/lustre/element/html.html#h3_"},{"doc":"sketch/lustre/element/html","title":"h4","content":"pub fn h4(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h4\nsketch/lustre/element/html h4","url":"sketch/lustre/element/html.html#h4"},{"doc":"sketch/lustre/element/html","title":"h4_","content":"pub fn h4_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h4_\nsketch/lustre/element/html h4_","url":"sketch/lustre/element/html.html#h4_"},{"doc":"sketch/lustre/element/html","title":"h5","content":"pub fn h5(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h5\nsketch/lustre/element/html h5","url":"sketch/lustre/element/html.html#h5"},{"doc":"sketch/lustre/element/html","title":"h5_","content":"pub fn h5_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h5_\nsketch/lustre/element/html h5_","url":"sketch/lustre/element/html.html#h5_"},{"doc":"sketch/lustre/element/html","title":"h6","content":"pub fn h6(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h6\nsketch/lustre/element/html h6","url":"sketch/lustre/element/html.html#h6"},{"doc":"sketch/lustre/element/html","title":"h6_","content":"pub fn h6_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.h6_\nsketch/lustre/element/html h6_","url":"sketch/lustre/element/html.html#h6_"},{"doc":"sketch/lustre/element/html","title":"head","content":"pub fn head(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.head\nsketch/lustre/element/html head","url":"sketch/lustre/element/html.html#head"},{"doc":"sketch/lustre/element/html","title":"header","content":"pub fn header(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.header\nsketch/lustre/element/html header","url":"sketch/lustre/element/html.html#header"},{"doc":"sketch/lustre/element/html","title":"header_","content":"pub fn header_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.header_\nsketch/lustre/element/html header_","url":"sketch/lustre/element/html.html#header_"},{"doc":"sketch/lustre/element/html","title":"hgroup","content":"pub fn hgroup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.hgroup\nsketch/lustre/element/html hgroup","url":"sketch/lustre/element/html.html#hgroup"},{"doc":"sketch/lustre/element/html","title":"hgroup_","content":"pub fn hgroup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.hgroup_\nsketch/lustre/element/html hgroup_","url":"sketch/lustre/element/html.html#hgroup_"},{"doc":"sketch/lustre/element/html","title":"hr","content":"pub fn hr(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.hr\nsketch/lustre/element/html hr","url":"sketch/lustre/element/html.html#hr"},{"doc":"sketch/lustre/element/html","title":"hr_","content":"pub fn hr_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.hr_\nsketch/lustre/element/html hr_","url":"sketch/lustre/element/html.html#hr_"},{"doc":"sketch/lustre/element/html","title":"html","content":"pub fn html(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.html\nsketch/lustre/element/html html","url":"sketch/lustre/element/html.html#html"},{"doc":"sketch/lustre/element/html","title":"i","content":"pub fn i(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.i\nsketch/lustre/element/html i","url":"sketch/lustre/element/html.html#i"},{"doc":"sketch/lustre/element/html","title":"i_","content":"pub fn i_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.i_\nsketch/lustre/element/html i_","url":"sketch/lustre/element/html.html#i_"},{"doc":"sketch/lustre/element/html","title":"iframe","content":"pub fn iframe(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.iframe\nsketch/lustre/element/html iframe","url":"sketch/lustre/element/html.html#iframe"},{"doc":"sketch/lustre/element/html","title":"iframe_","content":"pub fn iframe_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.iframe_\nsketch/lustre/element/html iframe_","url":"sketch/lustre/element/html.html#iframe_"},{"doc":"sketch/lustre/element/html","title":"img","content":"pub fn img(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.img\nsketch/lustre/element/html img","url":"sketch/lustre/element/html.html#img"},{"doc":"sketch/lustre/element/html","title":"img_","content":"pub fn img_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.img_\nsketch/lustre/element/html img_","url":"sketch/lustre/element/html.html#img_"},{"doc":"sketch/lustre/element/html","title":"input","content":"pub fn input(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.input\nsketch/lustre/element/html input","url":"sketch/lustre/element/html.html#input"},{"doc":"sketch/lustre/element/html","title":"input_","content":"pub fn input_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.input_\nsketch/lustre/element/html input_","url":"sketch/lustre/element/html.html#input_"},{"doc":"sketch/lustre/element/html","title":"ins","content":"pub fn ins(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ins\nsketch/lustre/element/html ins","url":"sketch/lustre/element/html.html#ins"},{"doc":"sketch/lustre/element/html","title":"ins_","content":"pub fn ins_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ins_\nsketch/lustre/element/html ins_","url":"sketch/lustre/element/html.html#ins_"},{"doc":"sketch/lustre/element/html","title":"kbd","content":"pub fn kbd(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.kbd\nsketch/lustre/element/html kbd","url":"sketch/lustre/element/html.html#kbd"},{"doc":"sketch/lustre/element/html","title":"kbd_","content":"pub fn kbd_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.kbd_\nsketch/lustre/element/html kbd_","url":"sketch/lustre/element/html.html#kbd_"},{"doc":"sketch/lustre/element/html","title":"label","content":"pub fn label(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.label\nsketch/lustre/element/html label","url":"sketch/lustre/element/html.html#label"},{"doc":"sketch/lustre/element/html","title":"label_","content":"pub fn label_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.label_\nsketch/lustre/element/html label_","url":"sketch/lustre/element/html.html#label_"},{"doc":"sketch/lustre/element/html","title":"legend","content":"pub fn legend(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.legend\nsketch/lustre/element/html legend","url":"sketch/lustre/element/html.html#legend"},{"doc":"sketch/lustre/element/html","title":"legend_","content":"pub fn legend_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.legend_\nsketch/lustre/element/html legend_","url":"sketch/lustre/element/html.html#legend_"},{"doc":"sketch/lustre/element/html","title":"li","content":"pub fn li(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.li\nsketch/lustre/element/html li","url":"sketch/lustre/element/html.html#li"},{"doc":"sketch/lustre/element/html","title":"li_","content":"pub fn li_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.li_\nsketch/lustre/element/html li_","url":"sketch/lustre/element/html.html#li_"},{"doc":"sketch/lustre/element/html","title":"link","content":"pub fn link(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.link\nsketch/lustre/element/html link","url":"sketch/lustre/element/html.html#link"},{"doc":"sketch/lustre/element/html","title":"main","content":"pub fn main(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.main\nsketch/lustre/element/html main","url":"sketch/lustre/element/html.html#main"},{"doc":"sketch/lustre/element/html","title":"main_","content":"pub fn main_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.main_\nsketch/lustre/element/html main_","url":"sketch/lustre/element/html.html#main_"},{"doc":"sketch/lustre/element/html","title":"map","content":"pub fn map(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.map\nsketch/lustre/element/html map","url":"sketch/lustre/element/html.html#map"},{"doc":"sketch/lustre/element/html","title":"map_","content":"pub fn map_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.map_\nsketch/lustre/element/html map_","url":"sketch/lustre/element/html.html#map_"},{"doc":"sketch/lustre/element/html","title":"mark","content":"pub fn mark(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.mark\nsketch/lustre/element/html mark","url":"sketch/lustre/element/html.html#mark"},{"doc":"sketch/lustre/element/html","title":"mark_","content":"pub fn mark_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.mark_\nsketch/lustre/element/html mark_","url":"sketch/lustre/element/html.html#mark_"},{"doc":"sketch/lustre/element/html","title":"math","content":"pub fn math(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.math\nsketch/lustre/element/html math","url":"sketch/lustre/element/html.html#math"},{"doc":"sketch/lustre/element/html","title":"math_","content":"pub fn math_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.math_\nsketch/lustre/element/html math_","url":"sketch/lustre/element/html.html#math_"},{"doc":"sketch/lustre/element/html","title":"menu","content":"pub fn menu(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.menu\nsketch/lustre/element/html menu","url":"sketch/lustre/element/html.html#menu"},{"doc":"sketch/lustre/element/html","title":"menu_","content":"pub fn menu_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.menu_\nsketch/lustre/element/html menu_","url":"sketch/lustre/element/html.html#menu_"},{"doc":"sketch/lustre/element/html","title":"meta","content":"pub fn meta(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.meta\nsketch/lustre/element/html meta","url":"sketch/lustre/element/html.html#meta"},{"doc":"sketch/lustre/element/html","title":"meter","content":"pub fn meter(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.meter\nsketch/lustre/element/html meter","url":"sketch/lustre/element/html.html#meter"},{"doc":"sketch/lustre/element/html","title":"meter_","content":"pub fn meter_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.meter_\nsketch/lustre/element/html meter_","url":"sketch/lustre/element/html.html#meter_"},{"doc":"sketch/lustre/element/html","title":"nav","content":"pub fn nav(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.nav\nsketch/lustre/element/html nav","url":"sketch/lustre/element/html.html#nav"},{"doc":"sketch/lustre/element/html","title":"nav_","content":"pub fn nav_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.nav_\nsketch/lustre/element/html nav_","url":"sketch/lustre/element/html.html#nav_"},{"doc":"sketch/lustre/element/html","title":"noscript","content":"pub fn noscript(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.noscript\nsketch/lustre/element/html noscript","url":"sketch/lustre/element/html.html#noscript"},{"doc":"sketch/lustre/element/html","title":"noscript_","content":"pub fn noscript_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.noscript_\nsketch/lustre/element/html noscript_","url":"sketch/lustre/element/html.html#noscript_"},{"doc":"sketch/lustre/element/html","title":"object","content":"pub fn object(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.object\nsketch/lustre/element/html object","url":"sketch/lustre/element/html.html#object"},{"doc":"sketch/lustre/element/html","title":"object_","content":"pub fn object_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.object_\nsketch/lustre/element/html object_","url":"sketch/lustre/element/html.html#object_"},{"doc":"sketch/lustre/element/html","title":"ol","content":"pub fn ol(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ol\nsketch/lustre/element/html ol","url":"sketch/lustre/element/html.html#ol"},{"doc":"sketch/lustre/element/html","title":"ol_","content":"pub fn ol_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ol_\nsketch/lustre/element/html ol_","url":"sketch/lustre/element/html.html#ol_"},{"doc":"sketch/lustre/element/html","title":"optgroup","content":"pub fn optgroup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.optgroup\nsketch/lustre/element/html optgroup","url":"sketch/lustre/element/html.html#optgroup"},{"doc":"sketch/lustre/element/html","title":"optgroup_","content":"pub fn optgroup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.optgroup_\nsketch/lustre/element/html optgroup_","url":"sketch/lustre/element/html.html#optgroup_"},{"doc":"sketch/lustre/element/html","title":"option","content":"pub fn option(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.option\nsketch/lustre/element/html option","url":"sketch/lustre/element/html.html#option"},{"doc":"sketch/lustre/element/html","title":"option_","content":"pub fn option_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.option_\nsketch/lustre/element/html option_","url":"sketch/lustre/element/html.html#option_"},{"doc":"sketch/lustre/element/html","title":"output","content":"pub fn output(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.output\nsketch/lustre/element/html output","url":"sketch/lustre/element/html.html#output"},{"doc":"sketch/lustre/element/html","title":"output_","content":"pub fn output_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.output_\nsketch/lustre/element/html output_","url":"sketch/lustre/element/html.html#output_"},{"doc":"sketch/lustre/element/html","title":"p","content":"pub fn p(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.p\nsketch/lustre/element/html p","url":"sketch/lustre/element/html.html#p"},{"doc":"sketch/lustre/element/html","title":"p_","content":"pub fn p_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.p_\nsketch/lustre/element/html p_","url":"sketch/lustre/element/html.html#p_"},{"doc":"sketch/lustre/element/html","title":"picture","content":"pub fn picture(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.picture\nsketch/lustre/element/html picture","url":"sketch/lustre/element/html.html#picture"},{"doc":"sketch/lustre/element/html","title":"picture_","content":"pub fn picture_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.picture_\nsketch/lustre/element/html picture_","url":"sketch/lustre/element/html.html#picture_"},{"doc":"sketch/lustre/element/html","title":"portal","content":"pub fn portal(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.portal\nsketch/lustre/element/html portal","url":"sketch/lustre/element/html.html#portal"},{"doc":"sketch/lustre/element/html","title":"portal_","content":"pub fn portal_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.portal_\nsketch/lustre/element/html portal_","url":"sketch/lustre/element/html.html#portal_"},{"doc":"sketch/lustre/element/html","title":"pre","content":"pub fn pre(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.pre\nsketch/lustre/element/html pre","url":"sketch/lustre/element/html.html#pre"},{"doc":"sketch/lustre/element/html","title":"pre_","content":"pub fn pre_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.pre_\nsketch/lustre/element/html pre_","url":"sketch/lustre/element/html.html#pre_"},{"doc":"sketch/lustre/element/html","title":"progress","content":"pub fn progress(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.progress\nsketch/lustre/element/html progress","url":"sketch/lustre/element/html.html#progress"},{"doc":"sketch/lustre/element/html","title":"progress_","content":"pub fn progress_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.progress_\nsketch/lustre/element/html progress_","url":"sketch/lustre/element/html.html#progress_"},{"doc":"sketch/lustre/element/html","title":"q","content":"pub fn q(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.q\nsketch/lustre/element/html q","url":"sketch/lustre/element/html.html#q"},{"doc":"sketch/lustre/element/html","title":"q_","content":"pub fn q_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.q_\nsketch/lustre/element/html q_","url":"sketch/lustre/element/html.html#q_"},{"doc":"sketch/lustre/element/html","title":"rp","content":"pub fn rp(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.rp\nsketch/lustre/element/html rp","url":"sketch/lustre/element/html.html#rp"},{"doc":"sketch/lustre/element/html","title":"rp_","content":"pub fn rp_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.rp_\nsketch/lustre/element/html rp_","url":"sketch/lustre/element/html.html#rp_"},{"doc":"sketch/lustre/element/html","title":"rt","content":"pub fn rt(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.rt\nsketch/lustre/element/html rt","url":"sketch/lustre/element/html.html#rt"},{"doc":"sketch/lustre/element/html","title":"rt_","content":"pub fn rt_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.rt_\nsketch/lustre/element/html rt_","url":"sketch/lustre/element/html.html#rt_"},{"doc":"sketch/lustre/element/html","title":"ruby","content":"pub fn ruby(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ruby\nsketch/lustre/element/html ruby","url":"sketch/lustre/element/html.html#ruby"},{"doc":"sketch/lustre/element/html","title":"ruby_","content":"pub fn ruby_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ruby_\nsketch/lustre/element/html ruby_","url":"sketch/lustre/element/html.html#ruby_"},{"doc":"sketch/lustre/element/html","title":"s","content":"pub fn s(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.s\nsketch/lustre/element/html s","url":"sketch/lustre/element/html.html#s"},{"doc":"sketch/lustre/element/html","title":"s_","content":"pub fn s_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.s_\nsketch/lustre/element/html s_","url":"sketch/lustre/element/html.html#s_"},{"doc":"sketch/lustre/element/html","title":"samp","content":"pub fn samp(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.samp\nsketch/lustre/element/html samp","url":"sketch/lustre/element/html.html#samp"},{"doc":"sketch/lustre/element/html","title":"samp_","content":"pub fn samp_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.samp_\nsketch/lustre/element/html samp_","url":"sketch/lustre/element/html.html#samp_"},{"doc":"sketch/lustre/element/html","title":"script","content":"pub fn script(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.script\nsketch/lustre/element/html script","url":"sketch/lustre/element/html.html#script"},{"doc":"sketch/lustre/element/html","title":"script_","content":"pub fn script_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.script_\nsketch/lustre/element/html script_","url":"sketch/lustre/element/html.html#script_"},{"doc":"sketch/lustre/element/html","title":"search","content":"pub fn search(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.search\nsketch/lustre/element/html search","url":"sketch/lustre/element/html.html#search"},{"doc":"sketch/lustre/element/html","title":"search_","content":"pub fn search_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.search_\nsketch/lustre/element/html search_","url":"sketch/lustre/element/html.html#search_"},{"doc":"sketch/lustre/element/html","title":"section","content":"pub fn section(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.section\nsketch/lustre/element/html section","url":"sketch/lustre/element/html.html#section"},{"doc":"sketch/lustre/element/html","title":"section_","content":"pub fn section_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.section_\nsketch/lustre/element/html section_","url":"sketch/lustre/element/html.html#section_"},{"doc":"sketch/lustre/element/html","title":"select","content":"pub fn select(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.select\nsketch/lustre/element/html select","url":"sketch/lustre/element/html.html#select"},{"doc":"sketch/lustre/element/html","title":"select_","content":"pub fn select_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.select_\nsketch/lustre/element/html select_","url":"sketch/lustre/element/html.html#select_"},{"doc":"sketch/lustre/element/html","title":"slot","content":"pub fn slot(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.slot\nsketch/lustre/element/html slot","url":"sketch/lustre/element/html.html#slot"},{"doc":"sketch/lustre/element/html","title":"slot_","content":"pub fn slot_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.slot_\nsketch/lustre/element/html slot_","url":"sketch/lustre/element/html.html#slot_"},{"doc":"sketch/lustre/element/html","title":"small","content":"pub fn small(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.small\nsketch/lustre/element/html small","url":"sketch/lustre/element/html.html#small"},{"doc":"sketch/lustre/element/html","title":"small_","content":"pub fn small_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.small_\nsketch/lustre/element/html small_","url":"sketch/lustre/element/html.html#small_"},{"doc":"sketch/lustre/element/html","title":"source","content":"pub fn source(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.source\nsketch/lustre/element/html source","url":"sketch/lustre/element/html.html#source"},{"doc":"sketch/lustre/element/html","title":"source_","content":"pub fn source_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.source_\nsketch/lustre/element/html source_","url":"sketch/lustre/element/html.html#source_"},{"doc":"sketch/lustre/element/html","title":"span","content":"pub fn span(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.span\nsketch/lustre/element/html span","url":"sketch/lustre/element/html.html#span"},{"doc":"sketch/lustre/element/html","title":"span_","content":"pub fn span_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.span_\nsketch/lustre/element/html span_","url":"sketch/lustre/element/html.html#span_"},{"doc":"sketch/lustre/element/html","title":"strong","content":"pub fn strong(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.strong\nsketch/lustre/element/html strong","url":"sketch/lustre/element/html.html#strong"},{"doc":"sketch/lustre/element/html","title":"strong_","content":"pub fn strong_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.strong_\nsketch/lustre/element/html strong_","url":"sketch/lustre/element/html.html#strong_"},{"doc":"sketch/lustre/element/html","title":"style","content":"pub fn style(\n  attributes: List(Attribute(a)),\n  child: String,\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.style\nsketch/lustre/element/html style","url":"sketch/lustre/element/html.html#style"},{"doc":"sketch/lustre/element/html","title":"sub","content":"pub fn sub(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.sub\nsketch/lustre/element/html sub","url":"sketch/lustre/element/html.html#sub"},{"doc":"sketch/lustre/element/html","title":"sub_","content":"pub fn sub_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.sub_\nsketch/lustre/element/html sub_","url":"sketch/lustre/element/html.html#sub_"},{"doc":"sketch/lustre/element/html","title":"summary","content":"pub fn summary(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.summary\nsketch/lustre/element/html summary","url":"sketch/lustre/element/html.html#summary"},{"doc":"sketch/lustre/element/html","title":"summary_","content":"pub fn summary_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.summary_\nsketch/lustre/element/html summary_","url":"sketch/lustre/element/html.html#summary_"},{"doc":"sketch/lustre/element/html","title":"sup","content":"pub fn sup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.sup\nsketch/lustre/element/html sup","url":"sketch/lustre/element/html.html#sup"},{"doc":"sketch/lustre/element/html","title":"sup_","content":"pub fn sup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.sup_\nsketch/lustre/element/html sup_","url":"sketch/lustre/element/html.html#sup_"},{"doc":"sketch/lustre/element/html","title":"svg","content":"pub fn svg(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.svg\nsketch/lustre/element/html svg","url":"sketch/lustre/element/html.html#svg"},{"doc":"sketch/lustre/element/html","title":"svg_","content":"pub fn svg_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.svg_\nsketch/lustre/element/html svg_","url":"sketch/lustre/element/html.html#svg_"},{"doc":"sketch/lustre/element/html","title":"table","content":"pub fn table(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.table\nsketch/lustre/element/html table","url":"sketch/lustre/element/html.html#table"},{"doc":"sketch/lustre/element/html","title":"table_","content":"pub fn table_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.table_\nsketch/lustre/element/html table_","url":"sketch/lustre/element/html.html#table_"},{"doc":"sketch/lustre/element/html","title":"tbody","content":"pub fn tbody(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.tbody\nsketch/lustre/element/html tbody","url":"sketch/lustre/element/html.html#tbody"},{"doc":"sketch/lustre/element/html","title":"tbody_","content":"pub fn tbody_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.tbody_\nsketch/lustre/element/html tbody_","url":"sketch/lustre/element/html.html#tbody_"},{"doc":"sketch/lustre/element/html","title":"td","content":"pub fn td(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.td\nsketch/lustre/element/html td","url":"sketch/lustre/element/html.html#td"},{"doc":"sketch/lustre/element/html","title":"td_","content":"pub fn td_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.td_\nsketch/lustre/element/html td_","url":"sketch/lustre/element/html.html#td_"},{"doc":"sketch/lustre/element/html","title":"template","content":"pub fn template(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.template\nsketch/lustre/element/html template","url":"sketch/lustre/element/html.html#template"},{"doc":"sketch/lustre/element/html","title":"template_","content":"pub fn template_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.template_\nsketch/lustre/element/html template_","url":"sketch/lustre/element/html.html#template_"},{"doc":"sketch/lustre/element/html","title":"text","content":"pub fn text(content: String) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.text\nsketch/lustre/element/html text","url":"sketch/lustre/element/html.html#text"},{"doc":"sketch/lustre/element/html","title":"textarea","content":"pub fn textarea(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.textarea\nsketch/lustre/element/html textarea","url":"sketch/lustre/element/html.html#textarea"},{"doc":"sketch/lustre/element/html","title":"textarea_","content":"pub fn textarea_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.textarea_\nsketch/lustre/element/html textarea_","url":"sketch/lustre/element/html.html#textarea_"},{"doc":"sketch/lustre/element/html","title":"tfoot","content":"pub fn tfoot(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.tfoot\nsketch/lustre/element/html tfoot","url":"sketch/lustre/element/html.html#tfoot"},{"doc":"sketch/lustre/element/html","title":"tfoot_","content":"pub fn tfoot_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.tfoot_\nsketch/lustre/element/html tfoot_","url":"sketch/lustre/element/html.html#tfoot_"},{"doc":"sketch/lustre/element/html","title":"th","content":"pub fn th(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.th\nsketch/lustre/element/html th","url":"sketch/lustre/element/html.html#th"},{"doc":"sketch/lustre/element/html","title":"th_","content":"pub fn th_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.th_\nsketch/lustre/element/html th_","url":"sketch/lustre/element/html.html#th_"},{"doc":"sketch/lustre/element/html","title":"thead","content":"pub fn thead(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.thead\nsketch/lustre/element/html thead","url":"sketch/lustre/element/html.html#thead"},{"doc":"sketch/lustre/element/html","title":"thead_","content":"pub fn thead_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.thead_\nsketch/lustre/element/html thead_","url":"sketch/lustre/element/html.html#thead_"},{"doc":"sketch/lustre/element/html","title":"time","content":"pub fn time(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.time\nsketch/lustre/element/html time","url":"sketch/lustre/element/html.html#time"},{"doc":"sketch/lustre/element/html","title":"time_","content":"pub fn time_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.time_\nsketch/lustre/element/html time_","url":"sketch/lustre/element/html.html#time_"},{"doc":"sketch/lustre/element/html","title":"title","content":"pub fn title(\n  attributes: List(Attribute(a)),\n  title: String,\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.title\nsketch/lustre/element/html title","url":"sketch/lustre/element/html.html#title"},{"doc":"sketch/lustre/element/html","title":"tr","content":"pub fn tr(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.tr\nsketch/lustre/element/html tr","url":"sketch/lustre/element/html.html#tr"},{"doc":"sketch/lustre/element/html","title":"tr_","content":"pub fn tr_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.tr_\nsketch/lustre/element/html tr_","url":"sketch/lustre/element/html.html#tr_"},{"doc":"sketch/lustre/element/html","title":"track","content":"pub fn track(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.track\nsketch/lustre/element/html track","url":"sketch/lustre/element/html.html#track"},{"doc":"sketch/lustre/element/html","title":"track_","content":"pub fn track_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.track_\nsketch/lustre/element/html track_","url":"sketch/lustre/element/html.html#track_"},{"doc":"sketch/lustre/element/html","title":"u","content":"pub fn u(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.u\nsketch/lustre/element/html u","url":"sketch/lustre/element/html.html#u"},{"doc":"sketch/lustre/element/html","title":"u_","content":"pub fn u_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.u_\nsketch/lustre/element/html u_","url":"sketch/lustre/element/html.html#u_"},{"doc":"sketch/lustre/element/html","title":"ul","content":"pub fn ul(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ul\nsketch/lustre/element/html ul","url":"sketch/lustre/element/html.html#ul"},{"doc":"sketch/lustre/element/html","title":"ul_","content":"pub fn ul_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.ul_\nsketch/lustre/element/html ul_","url":"sketch/lustre/element/html.html#ul_"},{"doc":"sketch/lustre/element/html","title":"var","content":"pub fn var(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.var\nsketch/lustre/element/html var","url":"sketch/lustre/element/html.html#var"},{"doc":"sketch/lustre/element/html","title":"var_","content":"pub fn var_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.var_\nsketch/lustre/element/html var_","url":"sketch/lustre/element/html.html#var_"},{"doc":"sketch/lustre/element/html","title":"video","content":"pub fn video(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.video\nsketch/lustre/element/html video","url":"sketch/lustre/element/html.html#video"},{"doc":"sketch/lustre/element/html","title":"video_","content":"pub fn video_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.video_\nsketch/lustre/element/html video_","url":"sketch/lustre/element/html.html#video_"},{"doc":"sketch/lustre/element/html","title":"wbr","content":"pub fn wbr(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.wbr\nsketch/lustre/element/html wbr","url":"sketch/lustre/element/html.html#wbr"},{"doc":"sketch/lustre/element/html","title":"wbr_","content":"pub fn wbr_(attributes: List(Attribute(a))) -&gt; Element(a)\n\nSynonyms:\nsketch/lustre/element/html.wbr_\nsketch/lustre/element/html wbr_","url":"sketch/lustre/element/html.html#wbr_"},{"doc":"sketch/lustre/element/html","title":"sketch/lustre/element/html","content":"","url":"sketch/lustre/element/html.html"}]);